//
//  RadioController.h
//  RadioTest
//
//  Created by Corey Stevens on 8/9/2010.
//  Copyright 2010 Starchaser Technology. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <STCRadioController/RadioDriverDelegate.h>
#import <STCRadioController/RadioDriver.h>
#import <STCRadioController/RadioControllerDelegate.h>
#import <STCRadioController/RadioEnumerations.h>
#import <STCRadioController/RadioSharkDriver.h>


@interface RadioController : NSObject <RadioDriverDelegate> {
	//General
	RCRadioDriver activeDriver;
	RCRadioBand activeBand;
	double currentStation;
	
	int lastAMStation;
	double lastFMStation;
	double lastHDStation;
	int lastSirriusXMStation;
	
	//Delegate
	id delegate;
	
	//Availability
	BOOL amAvailable;
	BOOL fmAvailable;
	BOOL hdAvailable;
	BOOL sirriusXMAvailable;
	
	//Tunning Settings
	RCFMTuningSettings tuningSetting;
	RCAMTuningSettings amTuningSetting;
	int amMinimum;
	int amMaximum;
	double fmMinimum;
	double fmMaximum;
	
	//Griffin RadioShark
	RadioSharkDriver* sharkDriver;
	
	
}

@property RCRadioBand activeBand;
@property double currentStation;

@property int lastAMStation;
@property double lastFMStation;
@property double lastHDStation;
@property int lastSirriusXMStation;

@property(readonly) BOOL amAvailable;
@property(readonly) BOOL fmAvailable;
@property(readonly) BOOL hdAvailable;
@property(readonly) BOOL sirriusXMAvailable;
@property(readonly) int amMinimum;
@property(readonly) int amMaximum;
@property(readonly) double fmMinimum;
@property(readonly) double fmMaximum;
@property RCFMTuningSettings fmtuningSetting;
@property RCAMTuningSettings amTuningSetting;

-(RadioController*)initWithDelegate:(id)theDelegate;

+(RadioController*)radioControllerWithDelegate:(id)theDelegate;

-(void)setActiveBand:(RCRadioBand)newBand andStation:(double)newStation;

-(double)tuneToStation:(double)newStation;

-(void)powerOn;
-(void)powerOnBand:(RCRadioBand)band andStation:(double)newStation;
-(void)powerOff;
@end
